@@ -129,7 +129,7 @@ class SipGenerator(object):
         #
         source = h_file
         self.unpreprocessed_source = []
-        with open(source, "rU") as f:
+        with open(source, "rb") as f:
             for line in f:
                 self.unpreprocessed_source.append(line)
 
@@ -416,7 +416,10 @@ class SipGenerator(object):
 
     def _enum_get(self, container, enum, level):
         pad = " " * (level * 4)
-        decl = pad + "enum {} {{\n".format(enum.displayname)
+        scoped = ""
+        if enum.is_scoped_enum():
+            scoped = "class "
+        decl = pad + "enum {}{} {{\n".format(scoped, enum.displayname)
         enumerations = []
         for enum in enum.get_children():
             #
@@ -609,7 +612,10 @@ class SipGenerator(object):
                 typeText = text
                 typeInit = ""
 
-            prefix = parameterType.spelling.rsplit("::", 1)[0]
+            if parameterType.kind == TypeKind.ENUM and parameterType.get_declaration().is_scoped_enum():
+                prefix = parameterType.spelling
+            else:
+                prefix = parameterType.spelling.rsplit("::", 1)[0]
             if "::" in typeText:
                 typeText = typeText.rsplit("::", 1)[1]
             return prefix + "::" + typeText + typeInit
@@ -733,6 +739,7 @@ class SipGenerator(object):
 
         :param extent:              The range of text required.
         """
+        # Extent columns are specified in bytes
         extract = self.unpreprocessed_source[extent.start.line - 1:extent.end.line]
         if extent.start.line == extent.end.line:
             extract[0] = extract[0][extent.start.column - 1:extent.end.column - 1]
@@ -741,8 +748,9 @@ class SipGenerator(object):
             extract[-1] = extract[-1][:extent.end.column - 1]
         #
         # Return a single line of text.
+        # Replace all kinds of newline variants (DOS, UNIX, MAC style) by single spaces
         #
-        return "".join(extract).replace("\n", " ")
+        return b''.join(extract).decode('utf-8').replace("\r\n", " ").replace("\n", " ").replace("\r", " ")
 
     @staticmethod
     def _report_ignoring(parent, child, text=None):
